using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;

namespace Sprite_Demo
{
    
    public class Sprite
    {
        private ContentManager p_content;
        private SpriteBatch p_spriteBatch;
        public Texture2D image;
        public Vector2 position;
        public Color color;

        public Sprite(ContentManager content, SpriteBatch spriteBatch)
        {
            p_content = content;
            p_spriteBatch = spriteBatch;
            image = null;
            position = Vector2.Zero;
            color = Color.White;
        }

        public bool Load(string assetName)
        {
            try 
            { 
                image = p_content.Load<Texture2D>(assetName); 
            }
            catch (Exception) { return false; } 
            return true;
        }

        public void Draw()
        {
            p_spriteBatch.Draw(image, position, color);
        }
    }


    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        Viewport viewport;

        //experimental error handling variables
        bool errorState;
        string errorMessage;
        SpriteFont ErrorFont;

        Sprite sun;


        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
            errorMessage = "";
            errorState = false;
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            spriteBatch = new SpriteBatch(GraphicsDevice);
            ErrorFont = Content.Load<SpriteFont>("ErrorFont");

            //get screen dimensions
            viewport = GraphicsDevice.Viewport;
            
            //create sun sprite
            sun = new Sprite(Content, spriteBatch);
            if (!sun.Load("sun")) //rename asset to try out the error handler
            {
                errorState = true;
                errorMessage = "Asset file 'sun' not found.";
                return;
            }

            //center sun sprite on screen
            float x = (viewport.Width - sun.image.Width) / 2;
            float y = (viewport.Height - sun.image.Height) / 2;
            sun.position = new Vector2(x, y);
        }

        protected override void UnloadContent()
        {
        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);
            spriteBatch.Begin();

            //experimental error handler
            if (errorState)
            {
                spriteBatch.DrawString(ErrorFont, "CRITICAL ERROR", Vector2.Zero, Color.Red);
                spriteBatch.DrawString(ErrorFont, errorMessage, new Vector2(0,100), Color.Red);
            }
            else
            {
                sun.Draw();
            }

            spriteBatch.End();
            base.Draw(gameTime);
        }
    }
}
