using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;

namespace Sprite_Movement
{
    public class Sprite
    {
        private ContentManager p_content;
        private SpriteBatch p_spriteBatch;
        public Texture2D image;
        public Vector2 position;
        public Vector2 velocity;
        public Color color;

        public Sprite(ContentManager content, SpriteBatch spriteBatch)
        {
            p_content = content;
            p_spriteBatch = spriteBatch;
            image = null;
            position = Vector2.Zero;
            color = Color.White;
        }

        public bool Load(string assetName)
        {
            try
            {
                image = p_content.Load<Texture2D>(assetName);
            }
            catch (Exception) { return false; }
            return true;
        }

        public void Draw()
        {
            p_spriteBatch.Draw(image, position, color);
        }

        public void Move()
        {
            position += velocity;
        }
    }

    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;

        Sprite background;
        Sprite ship;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            spriteBatch = new SpriteBatch(GraphicsDevice);

            background = new Sprite(Content, spriteBatch);
            background.Load("craters800x480");

            ship = new Sprite(Content, spriteBatch);
            ship.Load("fatship256");
            ship.position = new Vector2(0, 240 - ship.image.Height / 2);
            ship.velocity = new Vector2(8.0f, 4.0f);
        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            //move the sprite
            ship.Move();

            //rebound from top and bottom
            if (ship.position.Y < -70 | ship.position.Y > 480 - 185)
            {
                ship.velocity.Y *= -1;
            }

            //wrap around right to left
            if (ship.position.X > 800)
                ship.position.X = -256;

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);
            spriteBatch.Begin();

            //draw the background
            background.Draw();

            //draw the sprite
            ship.Draw();

            spriteBatch.End();
            base.Draw(gameTime);
        }
    }
}
