using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;

namespace Sprite_Rotation
{
    public class Sprite
    {
        private ContentManager p_content;
        private SpriteBatch p_spriteBatch;
        public Texture2D image;
        public Vector2 position;
        public Vector2 velocityLinear;
        public Color color;
        public float rotation;
        public float velocityAngular;

        public Sprite(ContentManager content, SpriteBatch spriteBatch)
        {
            p_content = content;
            p_spriteBatch = spriteBatch;
            image = null;
            position = Vector2.Zero;
            velocityLinear = Vector2.Zero;
            color = Color.White;
            rotation = 0.0f;
            velocityAngular = 0.0f;
        }

        public bool Load(string assetName)
        {
            try
            {
                image = p_content.Load<Texture2D>(assetName);
            }
            catch (Exception) { return false; }
            return true;
        }

        public void Draw()
        {
            Vector2 origin = new Vector2(image.Width/2,image.Height/2);
            float scale = 1.0f;
            p_spriteBatch.Draw(image, position, null, color, rotation, 
                origin, scale, SpriteEffects.None, 0.0f);
        }

        public void Move()
        {
            position += velocityLinear;
        }

        public void Rotate()
        {
            rotation += velocityAngular;
            if (rotation > Math.PI * 2)
                rotation = 0.0f;
            else if (rotation < 0.0f)
                rotation = (float)Math.PI * 2;
        }
    }


    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        Viewport screen;
        SpriteFont font;
        Sprite ship;

        
        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            spriteBatch = new SpriteBatch(GraphicsDevice);
            screen = GraphicsDevice.Viewport;

            //create the font
            font = Content.Load<SpriteFont>("WascoSans");

            //create the ship sprite
            ship = new Sprite(Content, spriteBatch);
            ship.Load("ship");
            ship.position = new Vector2(screen.Width/2, screen.Height/2);
        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            //get state of touch inputs
            TouchCollection touchInput = TouchPanel.GetState();

            //look at all touch points (usually 1)
            foreach (TouchLocation touch in touchInput)
            {
                if (touch.Position.X > screen.Width / 2)
                    ship.velocityAngular = 0.05f;
                else if (touch.Position.X < screen.Width / 2)
                    ship.velocityAngular = -0.05f;
            }

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.CornflowerBlue);
            spriteBatch.Begin();

            ship.Rotate();
            ship.Draw();

            string text = "Rotation: " + ship.rotation.ToString("N4");
            Vector2 size = font.MeasureString(text);
            float x = (screen.Width - size.X) / 2;
            spriteBatch.DrawString(font, text, new Vector2(x, 440), Color.White);

            spriteBatch.End();
            base.Draw(gameTime);
        }
    }
}
