using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;

namespace Machine_Gun
{
    public class Sprite
    {
        private ContentManager p_content;
        private SpriteBatch p_spriteBatch;
        public Texture2D image;
        public Vector2 position;
        public Vector2 velocityLinear;
        public Color color;
        public float rotation;
        public float velocityAngular;
        public Vector2 scaleV;
        public Vector2 origin;//
        public bool alive;//
        public bool visible;//

        public Sprite(ContentManager content, SpriteBatch spriteBatch)
        {
            p_content = content;
            p_spriteBatch = spriteBatch;
            image = null;
            position = Vector2.Zero;
            velocityLinear = Vector2.Zero;
            color = Color.White;
            rotation = 0.0f;
            velocityAngular = 0.0f;
            scaleV = new Vector2(1.0f);
            origin = Vector2.Zero;//
            alive = true;//
            visible = true;//
        }

        public float scale
        {
            get { return scaleV.X; }
            set
            {
                scaleV.X = value;
                scaleV.Y = value;
            }
        }

        public bool Load(string assetName)
        {
            try
            {
                image = p_content.Load<Texture2D>(assetName);
                origin = new Vector2(image.Width / 2, image.Height / 2);//
            }
            catch (Exception) { return false; }
            return true;
        }

        public void Draw()
        {
            //Vector2 origin = new Vector2(image.Width / 2, image.Height / 2);
            p_spriteBatch.Draw(image, position, null, color, rotation,
                origin, scaleV, SpriteEffects.None, 0.0f);
        }

        public void Move()
        {
            position += velocityLinear;
        }

        public void Rotate()
        {
            rotation += velocityAngular;
            if (rotation > Math.PI * 2)
                rotation -= (float)Math.PI * 2;//
            else if (rotation < 0.0f)
                rotation = (float)Math.PI * 2 - rotation;//
        }
    }

    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        Viewport screen;
        SpriteFont font;
        Sprite chopper;
        Texture2D bullet;
        Sprite[] bullets;
        float rotation;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            spriteBatch = new SpriteBatch(GraphicsDevice);
            screen = GraphicsDevice.Viewport;

            //create the font
            font = Content.Load<SpriteFont>("WascoSans");

            //create the helicopter sprite
            chopper = new Sprite(Content, spriteBatch);
            chopper.Load("apache");
            chopper.position = new Vector2(120, 240);
            chopper.origin = new Vector2(100, 22);

            //load bullet image
            bullet = Content.Load<Texture2D>("bullet");

            //create bullet sprites
            bullets = new Sprite[10];
            for (int n = 0; n < 10; n++)
            {
                bullets[n] = new Sprite(Content, spriteBatch);
                bullets[n].image = bullet;
                bullets[n].alive = false;
            }
        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            //get state of touch inputs
            TouchCollection touchInput = TouchPanel.GetState();

            //get rotation
            rotation = MathHelper.ToDegrees(chopper.rotation);

            //look at all touch points 
            foreach (TouchLocation touch in touchInput)
            {
                if (touch.Position.Y < 180) //top of screen
                    rotation -= 1.0f;
                else if (touch.Position.Y > 300) //bottom
                    rotation += 1.0f;
                else
                    Fire(); //middle
            }

            //keep rotation in bounds
            if (rotation < 0.0f)
                rotation = 360.0f - rotation;
            else if (rotation > 360.0f)
                rotation = 360.0f - rotation;

            //save rotation
            chopper.rotation = MathHelper.ToRadians(rotation);

            //move the bullets
            for (int n = 0; n < 10; n++)
            {
                if (bullets[n].alive)
                {
                    bullets[n].Move();
                    if (bullets[n].position.X > 800)
                        bullets[n].alive = false;
                }
            }

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.CornflowerBlue);
            spriteBatch.Begin();

            //draw the chopper
            chopper.Draw();

            //draw the bullets
            for (int n = 0; n < 10; n++)
            {
                if (bullets[n].alive)
                    bullets[n].Draw();
            }

            string text = "Angle: " + rotation.ToString("N4");
            spriteBatch.DrawString(font, text, new Vector2(200, 440), 
                Color.White);

            spriteBatch.End();
            base.Draw(gameTime);
        }

        void Fire()
        {
            //look for an unused bullet
            for (int n = 0; n < 10; n++)
            {
                if (!bullets[n].alive)
                {
                    bullets[n].alive = true;
                    bullets[n].position = chopper.position;
                    bullets[n].rotation = chopper.rotation;
                    //calculate angular velocity
                    float x = (float)Math.Cos(bullets[n].rotation) * 10.0f;
                    float y = (float)Math.Sin(bullets[n].rotation) * 10.0f;
                    bullets[n].velocityLinear = new Vector2(x,y);
                    break;
                }
            }
        }

    }
}
