using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;//

namespace Bounding_Box_Collision
{
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        Random rand;
        Viewport screen;
        SpriteFont font;
        Sprite[] asteroids;
        Sprite ship;
        int collisions = 0;
        int escapes = 0;
        int kills = 0;
        int hit = 0;

        const float SHIP_VEL = 1.5f;
        const float SHIP_ACCEL = 0.2f;
        const float ESCAPE_VEL = 2.5f;


        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            spriteBatch = new SpriteBatch(GraphicsDevice);
            screen = GraphicsDevice.Viewport;
            rand = new Random();
            font = Content.Load<SpriteFont>("WascoSans");

            //create asteroids
            asteroids = new Sprite[4];
            for (int n=0; n<4; n++)
            {
                asteroids[n] = new Sprite(Content, spriteBatch);
                asteroids[n].Load("asteroid");
                asteroids[n].position.Y = (n+1) * 90;
                asteroids[n].position.X = (float)rand.Next(0, 760);
                int factor = rand.Next(2, 12);
                asteroids[n].velocityLinear.X = (float)
                    ((double)factor * rand.NextDouble());
            }

            //create ship
            ship = new Sprite(Content, spriteBatch);
            ship.Load("ship");
            ship.position = new Vector2(390, screen.Height);
            ship.scale = 0.2f;
            ship.velocityLinear.Y = -SHIP_VEL;

        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            //move asteroids
            foreach (Sprite ast in asteroids)
            {
                ast.Move();
                if (ast.position.X < 0 - ast.image.Width)
                    ast.position.X = screen.Width;
                else if (ast.position.X > screen.Width)
                    ast.position.X = 0 - ast.image.Width;
            }

            //move ship
            ship.Move();
            if (ship.position.Y < 0)
            {
                ship.position.Y = screen.Height;
                escapes++;
            }


            //look for collision 
            foreach (Sprite ast in asteroids)
            {
                if (RadialCollision(ship, ast))
                {
                    //oh no, asteroid collision is imminent!
                    EvasiveManeuver(ast);
                    collisions++;
                    hit++;
                    //break;
                }
            }

            if (ship.velocityLinear.Y >= -SHIP_VEL)
            {
                ship.velocityLinear.Y -= SHIP_ACCEL;
                if (ship.velocityLinear.Y < -SHIP_VEL)
                    ship.velocityLinear.Y = -SHIP_VEL;
            }
            else if (ship.velocityLinear.Y < SHIP_VEL)
            {
                ship.velocityLinear.Y += SHIP_ACCEL;
                if (ship.velocityLinear.Y > SHIP_VEL)
                    ship.velocityLinear.Y = SHIP_VEL;
            }


            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);
            spriteBatch.Begin();

            foreach (Sprite ast in asteroids)
            {
                ast.Draw();
                ast.color = Color.White;
            }

            ship.Draw();


            string text = "Intersections:" + collisions.ToString();
            spriteBatch.DrawString(font, text, new Vector2(600, 0), Color.White);

            text = "Kills:" + kills.ToString();
            spriteBatch.DrawString(font, text, new Vector2(600, 25), Color.White);

            text = "Escapes:" + escapes.ToString();
            spriteBatch.DrawString(font, text, new Vector2(600, 50), Color.White);

            float survival = 100.0f - (100.0f / ((float)collisions / (float)kills));
            text = "Survival:" + survival.ToString("N2") + "%";
            spriteBatch.DrawString(font, text, new Vector2(600, 75), Color.White);

            spriteBatch.DrawString(font, ship.ToString(), new Vector2(0, 0), Color.White);


            spriteBatch.End();
            base.Draw(gameTime);
        }

        void EvasiveManeuver(Sprite ast)
        {
            ast.color = Color.Red;

            //shortcuts for ship
            int SW = (int)(float)(ship.image.Width * ship.scale);
            int SH = (int)(float)(ship.image.Height * ship.scale);
            int SX = (int)ship.position.X - SW/2;
            int SY = (int)ship.position.Y - SH/2;

            //create boundary boxes around the ship
            Rectangle[] boxes = new Rectangle[4];
            boxes[0] = ship.Boundary(); //upper
            boxes[0].Y -= SH;
            boxes[1] = ship.Boundary(); //lower
            boxes[1].Y += SH;
            boxes[2] = ship.Boundary(); //left
            boxes[2].X -= SW;
            boxes[3] = ship.Boundary(); //right
            boxes[3].X += SW;

            if (boxes[0].Intersects(ast.Boundary()))
                ship.velocityLinear.Y = SHIP_VEL * ESCAPE_VEL;
            else if (boxes[1].Intersects(ast.Boundary()))
                ship.velocityLinear.Y = -SHIP_VEL * ESCAPE_VEL;
            else if (boxes[2].Intersects(ast.Boundary()))
                ship.velocityLinear.Y = -SHIP_VEL * ESCAPE_VEL;
            else if (boxes[3].Intersects(ast.Boundary()))
                ship.velocityLinear.Y = -SHIP_VEL * ESCAPE_VEL;

            //check for a "kill", intersection with small inner box
            Rectangle kill = ship.Boundary();
            int shrinkh = kill.Width / 4;
            int shrinkv = kill.Height / 4;
            kill.Inflate(-shrinkh, -shrinkv);
            if (kill.Intersects(ast.Boundary()))
                kills++;

        }

        bool BoundaryCollision(Rectangle A, Rectangle B)
        {
            return A.Intersects(B);
        }

        bool RadialCollision(Sprite A, Sprite B)
        {
            float radius1 = A.image.Width / 2;
            float radius2 = B.image.Width / 2;
            return RadialCollision(A.position, B.position, radius1, radius2);
        }

        bool RadialCollision(Vector2 A, Vector2 B, float radius1, float radius2)
        {
            double diffX = A.X - B.X;
            double diffY = A.Y - B.Y;
            double dist = Math.Sqrt(Math.Pow(diffX, 2) + Math.Pow(diffY, 2));
            return (dist < radius1 + radius2);
        }

        float TargetAngle(Vector2 p1, Vector2 p2)
        {
            return TargetAngle(p1.X, p1.Y, p2.X, p2.Y);
        }

        float TargetAngle(double x1, double y1, double x2, double y2)
        {
            double deltaX = (x2 - x1);
            double deltaY = (y2 - y1);
            return (float)Math.Atan2(deltaY, deltaX);
        }


    }
}
