using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;

namespace GameLibrary
{
    public class Animation
    {
        public bool animating;

        public Animation()
        {
            animating = false;
        }

        public virtual void Update()
        {
        }

        public virtual Color ModifyColor(Color original)
        {
            return original;
        }

        public virtual Vector2 ModifyPosition(Vector2 original)
        {
            return original;
        }

        public virtual float ModifyRotation(float original)
        {
            return original;
        }

        public virtual float ModifyScale(float original)
        {
            return original;
        }
    }

    public class AnimationTemplate : Animation
    {
        public AnimationTemplate()
            : base()
        {
        }

        public void Update()
        {
        }
    }

    public class CycleColor : Animation
    {
        public int red, green, blue, alpha;

        public CycleColor(int red, int green, int blue, int alpha)
            : base()
        {
            this.red = red;
            this.green = green;
            this.blue = blue;
            this.alpha = alpha;
            animating = true;
        }

        public override Color ModifyColor(Color original)
        {
            Color modified = original;

            if (animating)
            {
                int R = original.R + red;
                int G = original.G + green;
                int B = original.B + blue;
                int A = original.A + alpha;

                if (R < 0 || R > 255 || G < 0 || G > 255 || B < 0 || B > 255 || A < 0 || A > 255)
                {
                    animating = false;
                }
                modified = new Color(R, G, B, A);
            }
            return modified;
        }
    }

}
