using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;

namespace Color_Bouncing
{
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        SpriteFont font;
        Texture2D shapeImage;
        List<Sprite> shapes;

        CycleColorBounce cycleRed, cycleGreen, cycleBlue;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            spriteBatch = new SpriteBatch(GraphicsDevice);
            font = Content.Load<SpriteFont>("WascoSans");

            shapeImage = Content.Load<Texture2D>("box");

            Sprite redBox = new Sprite(Content, spriteBatch);
            redBox.image = shapeImage;
            redBox.position = new Vector2(200, 240);
            redBox.origin = new Vector2(64, 64);
            redBox.color = new Color(255, 0, 0);

            Sprite greenBox = new Sprite(Content, spriteBatch);
            greenBox.image = shapeImage;
            greenBox.position = new Vector2(400, 240);
            greenBox.origin = new Vector2(64, 64);
            greenBox.color = new Color(0, 255, 0);

            Sprite blueBox = new Sprite(Content, spriteBatch);
            blueBox.image = shapeImage;
            blueBox.position = new Vector2(600, 240);
            blueBox.origin = new Vector2(64, 64);
            blueBox.color = new Color(0, 0, 255);


            cycleRed = new CycleColorBounce(-5, 0, 0, 0);
            cycleRed.rmin = 100;
            cycleRed.rmax = 200;
            redBox.SetAnimation(cycleRed);

            cycleGreen = new CycleColorBounce(0, -10, 0, 0);
            cycleGreen.gmin = 150;
            cycleGreen.gmax = 255;
            greenBox.SetAnimation(cycleGreen);

            cycleBlue = new CycleColorBounce(0, 0, -20, 0);
            cycleBlue.bmin = 0;
            cycleBlue.bmax = 255;
            blueBox.SetAnimation(cycleBlue);


            shapes = new List<Sprite>();
            shapes.Add(redBox);
            shapes.Add(greenBox);
            shapes.Add(blueBox);


        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            foreach (Sprite spr in shapes)
            {
                spr.Rotate();
                spr.Move();
            }

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);
            spriteBatch.Begin();

            foreach (Sprite spr in shapes)
            {
                spr.Animate();
                spr.Draw();
            }

            spriteBatch.DrawString(font, "Color Bouncing Demo", new Vector2(0, 0), Color.White);

            spriteBatch.End();
            base.Draw(gameTime);
        }

 
    }

}
