using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;

namespace Multiple_Animation_Demo
{
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        TouchLocation oldTouch;
        Random rand;
        SpriteFont font;
        Sprite ship;


        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
            oldTouch = new TouchLocation();
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            rand = new Random();
            spriteBatch = new SpriteBatch(GraphicsDevice);
            font = Content.Load<SpriteFont>("WascoSans");

            ship = new Sprite(Content, spriteBatch);
            ship.Load("ship");
            ship.position = new Vector2(400, 240);
            ship.rotation = (float)rand.NextDouble();
            
            ship.animations.Add(new Spin(0.1f));
            ship.animations.Add(new Throb(0.5f, 3.0f, 0.2f));

        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == 
                ButtonState.Pressed)
                this.Exit();

            //get state of touch input
            TouchCollection touchInput = TouchPanel.GetState();
            if (touchInput.Count > 0)
            {
                TouchLocation touch = touchInput[0];
                if (touch.State == TouchLocationState.Pressed &&
                    oldTouch.State == TouchLocationState.Released)
                {
                    ship.animations.Add(new Spin(0.1f));
                }
                oldTouch = touch;
            }


            ship.Rotate();
            ship.Move();

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);
            spriteBatch.Begin();

            ship.Animate();

            //reset throb 
            if (ship.animations.Count == 0)
                ship.animations.Add(new Throb(0.5f, 3.0f, 0.2f));


            ship.Draw();

            int anims = ship.animations.Count;
            spriteBatch.DrawString(font, "Tap screen to add animation...", new Vector2(0,0), Color.White);
            spriteBatch.DrawString(font, "Animations:" + anims.ToString(), new Vector2(600,0), Color.White);

            spriteBatch.End();
            base.Draw(gameTime);
        }
    }


}
