using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;

namespace Rotate_and_Scale_Animation_Demo
{
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        Random rand;
        SpriteFont font;
        List<Sprite> objects;
        ClockHand hours, minutes, seconds;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            rand = new Random();
            spriteBatch = new SpriteBatch(GraphicsDevice);
            font = Content.Load<SpriteFont>("WascoSans");

            objects = new List<Sprite>();

            Sprite clock = new Sprite(Content, spriteBatch);
            clock.Load("clock");
            clock.position = new Vector2(400, 240);
            objects.Add(clock);

            hours = new ClockHand(0);
            minutes = new ClockHand(0);
            seconds = new ClockHand(0);


            Sprite hourHand = new Sprite(Content, spriteBatch);
            hourHand.Load("arrow200");
            hourHand.position = new Vector2(400, 240);
            hourHand.origin = new Vector2(30, 199);
            hourHand.scaleV = new Vector2(1.5f, 0.7f);
            hourHand.color = new Color(250, 50, 250);
            hourHand.SetAnimation(hours);
            objects.Add(hourHand);

            Sprite minuteHand = new Sprite(Content, spriteBatch);
            minuteHand.Load("arrow200");
            minuteHand.position = new Vector2(400, 240);
            minuteHand.origin = new Vector2(30, 199);
            minuteHand.scaleV = new Vector2(1.0f, 0.9f);
            minuteHand.color = new Color(250, 100, 150);
            minuteHand.SetAnimation(minutes);
            objects.Add(minuteHand);

            Sprite secondHand = new Sprite(Content, spriteBatch);
            secondHand.Load("arrow200");
            secondHand.position = new Vector2(400, 240);
            secondHand.origin = new Vector2(30, 199);
            secondHand.scaleV = new Vector2(0.25f, 1.0f);
            secondHand.color = new Color(120, 80, 150);
            secondHand.SetAnimation(seconds);
            objects.Add(secondHand);

        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            foreach (Sprite spr in objects)
            {
                spr.Rotate();
                spr.Move();
            }

            hours.direction = DateTime.Now.Hour * 5;
            minutes.direction = DateTime.Now.Minute;
            seconds.direction = DateTime.Now.Second;
            

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);
            spriteBatch.Begin();

            foreach (Sprite spr in objects)
            {
                spr.Animate();
                spr.Draw();
            }

            spriteBatch.DrawString(font, "Rotate/Scale Animation Demo", new Vector2(0, 0), Color.White);

            spriteBatch.End();
            base.Draw(gameTime);
        }
    }

}
