using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;

namespace Transform_Animation_Demo
{
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        Random rand;
        SpriteFont font;
        Texture2D asteroidImg;
        List<Sprite> objects;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            rand = new Random();
            spriteBatch = new SpriteBatch(GraphicsDevice);
            font = Content.Load<SpriteFont>("WascoSans");

            objects = new List<Sprite>();

            Sprite blackhole = new Sprite(Content, spriteBatch);
            blackhole.Load("blackhole");
            blackhole.position = new Vector2(400, 240);
            blackhole.scale = 0.5f;
            blackhole.origin = new Vector2(64, 64);
            blackhole.velocityAngular = 1.0f;
            objects.Add(blackhole);


            asteroidImg = Content.Load<Texture2D>("asteroid");
            for (int n = 0; n < 500; n++)
            {
                Sprite ast = new Sprite(Content, spriteBatch);
                ast.image = asteroidImg;
                ast.origin = new Vector2(32, 32);
                ast.scale = 0.25f + (float)(rand.NextDouble() * 0.5);
                ast.velocityAngular = (float)(rand.NextDouble() * 0.1);
                Vector2 pos = new Vector2(380 + rand.Next(40), 220 + rand.Next(40));
                double angle = rand.NextDouble() * 6.0;
                int radius = rand.Next(60, 400);
                float velocity = (float)(rand.NextDouble() * 0.01 * ((400-radius) * 0.1) );
                ast.SetAnimation(new OrbitalMovement(pos, radius, angle, velocity));
                objects.Add(ast);
            }

        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            foreach (Sprite spr in objects)
            {
                spr.Move();
                spr.Rotate();
            }

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);
            spriteBatch.Begin();

            foreach (Sprite spr in objects)
            {
                spr.Animate();
                spr.Draw();
            }

            spriteBatch.DrawString(font, "Transform Animation Demo", new Vector2(0, 0), Color.White);

            spriteBatch.End();
            base.Draw(gameTime);
        }
    }

}
