using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;

namespace Frame_Animation_Demo
{
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        TouchLocation oldTouch;
        Random rand;
        SpriteFont font;
        List<Sprite> objects;
        Sprite fighter;
        int score = 0;
        int hits = 0;
        Sprite lastHit = null;


        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
            oldTouch = new TouchLocation();
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            rand = new Random();
            spriteBatch = new SpriteBatch(GraphicsDevice);
            font = Content.Load<SpriteFont>("WascoSans");

            //create object list
            objects = new List<Sprite>();

            //create fighter sprite
            fighter = new Sprite(Content, spriteBatch);
            fighter.Load("fighter");
            fighter.position = new Vector2(40, 240);
            fighter.rotation = MathHelper.ToRadians(90);

            //create asteroid sprites
            for (int n = 0; n < 20; n++)
            {
                Sprite ast = new Sprite(Content, spriteBatch);
                ast.Load("asteroid");
                ast.size = new Vector2(60, 60);
                ast.origin = new Vector2(30, 30);
                float x = 800 + (float)rand.Next(800);
                float y = (float)rand.Next(480);
                ast.position = new Vector2(x, y);
                ast.columns = 8;
                ast.totalFrames = 64;
                ast.frame = rand.Next(64);
                x = (float)(rand.NextDouble() * rand.Next(1, 10));
                y = 0;
                ast.velocityLinear = new Vector2(-x, y);
                objects.Add(ast);
            }

        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back ==
                ButtonState.Pressed)
                this.Exit();

            //get state of touch input
            TouchCollection touchInput = TouchPanel.GetState();
            if (touchInput.Count > 0)
            {
                TouchLocation touch = touchInput[0];
                if (touch.State == TouchLocationState.Pressed)
                {
                    if (touch.Position.Y < fighter.Y )
                    {
                        fighter.velocityLinear.Y -= 1.0f;
                    }
                    else if (touch.Position.Y >= fighter.Y)
                    {
                        fighter.velocityLinear.Y += 1.0f;
                    }
                }
                oldTouch = touch;
            }

            //gradually reduce velocity
            if (fighter.velocityLinear.Y < 0)
                fighter.velocityLinear.Y += 0.05f;
            else if (fighter.velocityLinear.Y > 0)
                fighter.velocityLinear.Y -= 0.05f;

            //keep fighter in screen bounds
            if (fighter.Y < -32)
            {
                fighter.Y = -32;
                fighter.velocityLinear.Y = 0;
            }
            else if (fighter.Y > 480-32)
            {
                fighter.Y = 480-32;
                fighter.velocityLinear.Y = 0;
            }

            fighter.Move();

            //update all objects
            foreach (Sprite spr in objects)
            {
                spr.Rotate();
                spr.Move();

                //wrap asteroids around screen
                if (spr.X < -60)
                {
                    spr.X = 800;
                    score++;
                }

                //look for collision with fighter
                if (fighter.Boundary().Intersects(spr.Boundary()))
                {
                    hits++;
                    spr.X = 800;
                }

            }

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);
            spriteBatch.Begin();

            foreach (Sprite spr in objects)
            {
                spr.Animate(gameTime.ElapsedGameTime.Milliseconds);
                spr.Draw();
            }

            fighter.Draw();

            spriteBatch.DrawString(font, "Score:" + score.ToString() + 
                ", Hits:" + hits.ToString(), Vector2.Zero, Color.White);
            
            spriteBatch.End();
            base.Draw(gameTime);
        }
    }



}
