using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;

namespace Z_Index_Demo
{
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        TouchLocation oldTouch;
        Random rand;
        SpriteFont font;
        List<Sprite> objects;
        Texture2D asteroidImage;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
            oldTouch = new TouchLocation();
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            rand = new Random();
            spriteBatch = new SpriteBatch(GraphicsDevice);
            font = Content.Load<SpriteFont>("WascoSans");

            //create object list
            objects = new List<Sprite>();

            //create shuttle sprite
            Sprite shuttle = new Sprite(Content, spriteBatch);
            shuttle.Load("shuttle");
            shuttle.scale = 0.4f;
            shuttle.position = new Vector2(0, 240);
            shuttle.rotation = MathHelper.ToRadians(90);
            shuttle.velocityLinear = new Vector2(4, 0);
            Rectangle bounds = new Rectangle(-80, 0, 800 + 180, 480);
            shuttle.animations.Add(new WrapBoundary(bounds));
            shuttle.zindex = 0.5f;
            objects.Add(shuttle);


            //load asteroid image
            asteroidImage = Content.Load<Texture2D>("asteroid");

            //create asteroid sprites with increasing z-index
            for (int row = 0; row < 13; row++)
            {
                float zindex = row / 12.0f;
                for (int col = 0; col < 8; col++)
                {
                    Sprite spr = new Sprite(Content, spriteBatch);
                    spr.image = asteroidImage;
                    spr.columns = 8;
                    spr.totalFrames = 64;
                    spr.animations.Add(new FrameLoop(0, 63, 1));
                    spr.position = new Vector2(30 + 60 * row, 30 + col * 60);
                    spr.size = new Vector2(60, 60);
                    spr.zindex = zindex;
                    objects.Add(spr);
                }
            }
        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back ==
                ButtonState.Pressed)
                this.Exit();

            //get state of touch input
            TouchCollection touchInput = TouchPanel.GetState();
            if (touchInput.Count > 0)
            {
                TouchLocation touch = touchInput[0];
                if (touch.State == TouchLocationState.Pressed)
                {
                }
                oldTouch = touch;
            }

            //update all objects
            foreach (Sprite spr in objects)
            {
                spr.Rotate();
                spr.Move();
            }

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);
            spriteBatch.Begin(SpriteSortMode.FrontToBack, BlendState.AlphaBlend);

            foreach (Sprite spr in objects)
            {
                spr.Animate();
                spr.Draw();
            }

            spriteBatch.DrawString(font, "", Vector2.Zero, Color.White);

            spriteBatch.End();
            base.Draw(gameTime);
        }
    }

}
