using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;

namespace Audio_Demo
{
    public class Button : Sprite
    {
        public string text;
        private SpriteBatch p_spriteBatch;
        private SpriteFont p_font;

        public Button(ContentManager content, SpriteBatch spriteBatch, 
            SpriteFont font) : base(content, spriteBatch)
        { 
            p_spriteBatch = spriteBatch;
            p_font = font;
            Load("button");
            text = "";
            color = Color.LightGreen;
        } 

        public void Draw()
        {
            base.Draw();
            Vector2 size = p_font.MeasureString(text);
            Vector2 pos = position;
            pos.X -= size.X / 2;
            pos.Y -= size.Y / 2;
            p_spriteBatch.DrawString(p_font, text, pos, color);
        }

        public bool Tapped(Vector2 pos)
        {
            Rectangle rect = new Rectangle((int)pos.X, (int)pos.Y, 1, 1);
            return Boundary().Intersects(rect);
        }
    }

    public class MySoundEffect
    {
        private ContentManager p_content;
        public SoundEffect effect;
        public SoundEffectInstance instance;

        public MySoundEffect(ContentManager content)
        {
            p_content = content;
            effect = null;
            instance = null;
        }

        public void Load(string assetName)
        {
            effect = p_content.Load<SoundEffect>(assetName);
            instance = effect.CreateInstance();
        }
    }

    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        TouchLocation oldTouch;
        SpriteFont font;

        Button[] buttons;

        MySoundEffect[] sounds;
        int current = -1;


        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
            oldTouch = new TouchLocation();
        }

        protected override void Initialize()
        {
            base.Initialize();
            this.IsMouseVisible = true;
        }

        protected override void LoadContent()
        {
            spriteBatch = new SpriteBatch(GraphicsDevice);
            font = Content.Load<SpriteFont>("WascoSans");

            //create buttons
            buttons = new Button[5];
            for (int n = 0; n < 5; n++)
            {
                buttons[n] = new Button(Content, spriteBatch, font);
                buttons[n].text = (n+1).ToString();
                buttons[n].position = new Vector2(100 + 110 * n, 200);
            }
            
            //create sound clips
            sounds = new MySoundEffect[5];
            for (int n = 0; n < 5; n++)
            {
                sounds[n] = new MySoundEffect(Content);
                sounds[n].Load("Audio//clip" + (n+1).ToString());
            }

        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back ==
                ButtonState.Pressed)
                this.Exit();

            //get state of touch input
            TouchCollection touchInput = TouchPanel.GetState();
            if (touchInput.Count > 0)
            {
                TouchLocation touch = touchInput[0];
                if (touch.State == TouchLocationState.Pressed)
                {
                    current = -1;
                    int n = 0;
                    foreach (Button b in buttons)
                    {
                        int x = (int)touch.Position.X;
                        int y = (int)touch.Position.Y;
                        if (b.Boundary().Contains(x,y))
                        {
                            current = n;
                            sounds[current].instance.Play();
                            break;
                        }
                        n++;
                    }
                }
                oldTouch = touch;
            }

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);
            spriteBatch.Begin(SpriteSortMode.FrontToBack,
                BlendState.AlphaBlend);

            spriteBatch.DrawString(font, "Audio Demo", Vector2.Zero, Color.White);

            foreach (Button b in buttons)
            {
                b.Draw();
            }

            if (current > -1)
            {
                string text = "Clip length: " + sounds[current].effect.Duration.ToString();
                spriteBatch.DrawString(font, text, new Vector2(0, 400), Color.White);
            }

            spriteBatch.End();
            base.Draw(gameTime);
        }

    }
}
