using System;
using System.Collections.Generic;
using System.IO;
using System.IO.IsolatedStorage;
using System.Xml;
using System.Xml.Serialization;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using GameLibrary;

namespace Project
{
    public class Button : Sprite
    {
        public string text;
        private SpriteBatch p_spriteBatch;
        private SpriteFont p_font;

        public Button(ContentManager content, SpriteBatch spriteBatch, SpriteFont font)
            : base(content, spriteBatch)
        {
            p_spriteBatch = spriteBatch;
            p_font = font;
            Load("button");
            text = "";
            color = Color.LightGreen;
        }

        public void Draw()
        {
            base.Draw();
            Vector2 size = p_font.MeasureString(text);
            Vector2 pos = position;
            pos.X -= size.X / 2;
            pos.Y -= size.Y / 2;
            p_spriteBatch.DrawString(p_font, text, pos, color);
        }

        public bool Tapped(Vector2 pos)
        {
            Rectangle rect = new Rectangle((int)pos.X, (int)pos.Y, 1, 1);
            return Boundary().Intersects(rect);
        }
    }

    public struct SaveGameData
    {
        public string Name;
        public int Score;
    }

    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        SpriteFont font;
        Random rand;
        TouchLocation oldTouch;
        Button[] buttons;
        int current = -1;
        bool loaded = false;

        SaveGameData savedata;


        const string directory = "StorageDemo";
        const string filename = directory + "\\savegame.dat";

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
            oldTouch = new TouchLocation();
            rand = new Random();
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            spriteBatch = new SpriteBatch(GraphicsDevice);
            font = Content.Load<SpriteFont>("WascoSans");

            //create save button
            buttons = new Button[2];
            buttons[0] = new Button(Content, spriteBatch, font);
            buttons[0].text = "Save";
            buttons[0].position = new Vector2(100, 100);

            //create load button
            buttons[1] = new Button(Content, spriteBatch, font);
            buttons[1].text = "Load";
            buttons[1].position = new Vector2(300, 100);

        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back ==
                ButtonState.Pressed)
                this.Exit();

            //get state of touch input
            TouchCollection touchInput = TouchPanel.GetState();
            if (touchInput.Count > 0)
            {
                TouchLocation touch = touchInput[0];
                if (touch.State == TouchLocationState.Pressed)
                {
                    current = -1;
                    int n = 0;
                    foreach (Button b in buttons)
                    {
                        int x = (int)touch.Position.X;
                        int y = (int)touch.Position.Y;
                        if (b.Boundary().Contains(x, y))
                        {
                            current = n;
                            break;
                        }
                        n++;
                    }
                }
                oldTouch = touch;
            }

            if (current == 0)
            {
                savedata = new SaveGameData();
                savedata.Name = "John Doe";
                savedata.Score = rand.Next(500, 5000);
                SaveData(savedata);
                loaded = false;
                current = -1;
            }
            else if (current == 1)
            {
                savedata = LoadData();
                loaded = true;
                current = -1;
            }



            base.Update(gameTime);
        }
   
        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);
            spriteBatch.Begin(SpriteSortMode.FrontToBack, BlendState.AlphaBlend);

            print(0, 0, "Storage Demo", Color.White);

            foreach (Button b in buttons)
            {
                b.Draw();
            }

            if (loaded)
            {
                print(100, 200, "Loaded data:\n\n" +
                    "Name: " + savedata.Name + "\n" +
                    "Score: " + savedata.Score.ToString() + "\n", 
                    Color.White);
            }

            spriteBatch.End();
            base.Draw(gameTime);
        }

        void print(int x, int y, string text, Color color)
        {
            var pos = new Vector2((float)x, (float)y);
            spriteBatch.DrawString(font, text, pos, color);
        }

        private void SaveData(SaveGameData data)
        {
            var storage = IsolatedStorageFile.GetUserStoreForApplication();

            //create directory for data
            if (!storage.DirectoryExists(directory))
                storage.CreateDirectory(directory);

            //delete any existing file
            if (storage.FileExists(filename))
                storage.DeleteFile(filename);


            //create new savegame file
            using (var fstream = new IsolatedStorageFileStream(filename, FileMode.CreateNew, storage))
            {
                XmlSerializer serializer = new XmlSerializer(typeof(SaveGameData));
                serializer.Serialize(fstream, data);
            }
        }


        private SaveGameData LoadData()
        {
            SaveGameData data;

            var storage = IsolatedStorageFile.GetUserStoreForApplication();

            using (var fstream = new IsolatedStorageFileStream(filename, FileMode.Open, storage))
            {
                XmlSerializer serializer = new XmlSerializer(typeof(SaveGameData));
                data = (SaveGameData)serializer.Deserialize(fstream);
            }

            return data;
        }

    }
}
