using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;

namespace GUI_Demo
{
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        SpriteFont font;
        Random rand;
        TouchLocation oldTouch;

        Label lblTitle, lblColor;
        Button[] buttons;
        HSlider[] hsliders;
        VSlider vslider;
        Color bgcolor;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
            oldTouch = new TouchLocation();
            rand = new Random();
            bgcolor = Color.CornflowerBlue;
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            spriteBatch = new SpriteBatch(GraphicsDevice);
            font = Content.Load<SpriteFont>("WascoSans");

            lblTitle = new Label(Content, spriteBatch, font);
            lblTitle.text = "Graphical User Interface Demo";
            lblTitle.position = new Vector2(400 - lblTitle.TextSize().X / 2, 0);

            //create buttons
            buttons = new Button[4];
            buttons[0] = new Button(Content, spriteBatch, font);
            buttons[0].text = "RED";
            buttons[0].position = new Vector2(400, 150);
            buttons[0].textColor = Color.Red;
            buttons[0].color = Color.DarkRed;
            buttons[0].scaleV = new Vector2(1.5f, 1.0f);

            buttons[1] = new Button(Content, spriteBatch, font);
            buttons[1].text = "GREEN";
            buttons[1].position = new Vector2(400, 230);
            buttons[1].textColor = Color.Green;
            buttons[1].color = Color.DarkGreen;
            buttons[1].scaleV = new Vector2(1.5f, 1.0f);

            buttons[2] = new Button(Content, spriteBatch, font);
            buttons[2].text = "BLUE";
            buttons[2].position = new Vector2(400, 310);
            buttons[2].textColor = Color.Cyan;
            buttons[2].color = Color.DarkCyan;
            buttons[2].scaleV = new Vector2(1.5f, 1.0f);

            buttons[3] = new Button(Content, spriteBatch, font);
            buttons[3].text = "Exit";
            buttons[3].position = new Vector2(750, 450);
            buttons[3].scaleV = new Vector2(1.2f, 0.8f);

            //create horitonal sliders for color editing
            hsliders = new HSlider[3];
            hsliders[0] = new HSlider(Content, spriteBatch, font);
            hsliders[0].SetStartPosition(new Vector2(500, 150));
            hsliders[0].color = Color.Red;
            hsliders[0].Limit = 255;

            hsliders[1] = new HSlider(Content, spriteBatch, font);
            hsliders[1].SetStartPosition(new Vector2(500, 230));
            hsliders[1].color = Color.LightGreen;
            hsliders[1].Limit = 255;

            hsliders[2] = new HSlider(Content, spriteBatch, font);
            hsliders[2].SetStartPosition(new Vector2(500, 310));
            hsliders[2].color = Color.Cyan;
            hsliders[2].Limit = 255;

            //create vertical slider for bg color editin
            vslider = new VSlider(Content, spriteBatch, font);
            vslider.SetStartPosition(new Vector2(140, 170));
            vslider.color = Color.Yellow;
            vslider.Limit = 100;

            //create label for slider
            lblColor = new Label(Content, spriteBatch, font);
            lblColor.text = "Background Color";
            lblColor.position = new Vector2( 140 - lblColor.TextSize().X/2, 100);
        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back ==
                ButtonState.Pressed)
                this.Exit();

            TouchCollection touchInput = TouchPanel.GetState();
            if (touchInput.Count > 0)
            {
                TouchLocation touch = touchInput[0];
                oldTouch = touch;
                
                lblTitle.Update(touch);
                UpdateButtons(touch);
                UpdateSliders(touch);
                vslider.Update(touch);
                lblColor.Update(touch);
            }

            base.Update(gameTime);
        }

        void UpdateButtons(TouchLocation touch)
        {
            //update buttons
            int tapped = -1;
            for (int n = 0; n < buttons.Length; n++)
            {
                buttons[n].Update(touch);
                if (buttons[n].Tapped) tapped = n;
            }

            //was a button tapped?
            int c = rand.Next(256);
            switch (tapped)
            {
                case 0:
                    buttons[0].color = new Color(c, 0, 0);
                    hsliders[0].Value = c;
                    break;
                case 1:
                    buttons[1].color = new Color(0, c, 0);
                    hsliders[1].Value = c;
                    break;
                case 2:
                    buttons[2].color = new Color(0, 0, c);
                    hsliders[2].Value = c;
                    break;
                case 3:
                    this.Exit();
                    break;
            }
        }

        void UpdateSliders(TouchLocation touch)
        {
            //update horiztona sliders
            int moving = -1;
            for (int n = 0; n < hsliders.Length; n++)
            {
                hsliders[n].Update(touch);
                if (hsliders[n].Moving) moving = n;
            }

            switch(moving)
            {
                case 0:
                    buttons[0].color = new Color(hsliders[0].Value, 0, 0);
                    break;
                case 1:
                    buttons[1].color = new Color(0, hsliders[1].Value, 0);
                    break;
                case 2:
                    buttons[2].color = new Color(0, 0, hsliders[2].Value);
                    break;
            }

            //colorize Exit button based on colors
            buttons[3].color = new Color(hsliders[0].Value, hsliders[1].Value, hsliders[2].Value);


            //update vertical slider
            if (vslider.Moving)
            {
                bgcolor = Color.CornflowerBlue;
                bgcolor.R -= (byte)vslider.Value;
                bgcolor.G -= (byte)vslider.Value;
                bgcolor.B -= (byte)vslider.Value;
            }

        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(bgcolor);
            spriteBatch.Begin(SpriteSortMode.Deferred, BlendState.AlphaBlend);

            lblTitle.Draw();

            foreach (Button b in buttons)
                b.Draw();

            foreach (HSlider hs in hsliders)
                hs.Draw();

            vslider.Draw();
            lblColor.Draw();
            
            spriteBatch.End();
            base.Draw(gameTime);
        }

        void print(int x, int y, string text, Color color)
        {
            var pos = new Vector2((float)x, (float)y);
            spriteBatch.DrawString(font, text, pos, color);
        }

    }
}
