using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;

namespace Black_Hole_Game
{
    class TitleScreenModule : IGameModule
    {
        Game1 game;
        SpriteFont font;
        SpriteFont guifont;
        Random rand;
        Label lblTitle;
        Button[] btnMenu;

        public TitleScreenModule(Game1 game)
        {
            this.game = game;
            rand = new Random();
        }

        public void LoadContent(ContentManager content)
        {
            font = content.Load<SpriteFont>("WascoSans");
            guifont = content.Load<SpriteFont>("GUIFont");

            lblTitle = new Label(content, game.spriteBatch, font);
            lblTitle.text = "Title Screen";
            Vector2 size = font.MeasureString(lblTitle.text);
            lblTitle.position = new Vector2(400-size.X/2, 10);

            btnMenu = new Button[4];
            btnMenu[0] = new Button(content, game.spriteBatch, guifont);
            btnMenu[0].text = "Start Game";
            btnMenu[0].position = new Vector2(400, 160);
            btnMenu[0].scaleV = new Vector2(3.0f, 1.2f);

            btnMenu[1] = new Button(content, game.spriteBatch, guifont);
            btnMenu[1].text = "Options";
            btnMenu[1].position = new Vector2(400, 250);
            btnMenu[1].scaleV = new Vector2(3.0f, 1.2f);

            btnMenu[2] = new Button(content, game.spriteBatch, guifont);
            btnMenu[2].text = "Game Over";
            btnMenu[2].position = new Vector2(400, 340);
            btnMenu[2].scaleV = new Vector2(3.0f, 1.2f);

            btnMenu[3] = new Button(content, game.spriteBatch, guifont);
            btnMenu[3].text = "Exit";
            btnMenu[3].position = new Vector2(400, 430);
            btnMenu[3].scaleV = new Vector2(3.0f, 1.2f);
        }

        public void Update(TouchLocation touch, GameTime gameTime)
        {
            int tapped = -1;
            int n = 0;
            foreach (Button btn in btnMenu)
            {
                btn.Update(touch);
                if (btn.Tapped)
                    tapped = n;

                n++;
            }

            switch (tapped)
            {
                case 0: 
                    game.gameState = Game1.GameStates.PLAYING;
                    break;

                case 1:
                    game.gameState = Game1.GameStates.OPTIONS;
                    break;

                case 2:
                    game.gameState = Game1.GameStates.GAMEOVER;
                    break;

                case 3:
                    game.Exit();
                    break;
            }
        }

        public void Draw(GameTime gameTime)
        {
            lblTitle.Draw();

            foreach (Button btn in btnMenu)
            {
                btn.Draw();
            }
        }

    }
}

