using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;

namespace Black_Hole_Game
{
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        public enum GameState
        {
            TITLE = 0,
            PLAYING = 1,
            OPTIONS = 2,
            GAMEOVER = 3
        }

        public GraphicsDeviceManager graphics;
        public SpriteBatch spriteBatch;
        public GameState gameState;
        public Color backColor;
        SpriteFont font;
        Random rand;
        TouchLocation oldTouch;
        IGameModule[] modules;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
            oldTouch = new TouchLocation();
            rand = new Random();
            backColor = new Color(32, 32, 32);
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            spriteBatch = new SpriteBatch(GraphicsDevice);
            font = Content.Load<SpriteFont>("WascoSans");

            modules = new IGameModule[4];
            modules[0] = new TitleScreenModule(this);
            modules[1] = new PlayingModule(this);
            modules[2] = new OptionsModule(this);
            modules[3] = new GameOverModule(this);

            foreach (IGameModule mod in modules)
            {
                mod.LoadContent(Content);
            }

            gameState = GameState.PLAYING;


        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back ==
                ButtonState.Pressed)
                this.Exit();

            TouchCollection touchInput = TouchPanel.GetState();
            TouchLocation touch = new TouchLocation();
            if (touchInput.Count > 0)
            {
                touch = touchInput[0];
                oldTouch = touch;
            }


            //update current module
            modules[(int)gameState].Update(touch ,gameTime);


            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(backColor);
            spriteBatch.Begin(SpriteSortMode.Deferred, BlendState.AlphaBlend);

            //draw current module
            modules[(int)gameState].Draw(gameTime);

            spriteBatch.End();
            base.Draw(gameTime);
        }

        public bool BoundaryCollision(Rectangle A, Rectangle B)
        {
            return A.Intersects(B);
        }

        public bool RadialCollision(Sprite A, Sprite B)
        {
            float radius1 = A.image.Width / 2;
            float radius2 = B.image.Width / 2;
            return RadialCollision(A.position, B.position, radius1, radius2);
        }

        public bool RadialCollision(Vector2 A, Vector2 B, float radius1, float radius2)
        {
            float dist = Distance(A, B);
            return (dist < radius1 + radius2);
        }

        public float Distance(Vector2 A, Vector2 B)
        {
            double diffX = A.X - B.X;
            double diffY = A.Y - B.Y;
            double dist = Math.Sqrt(Math.Pow(diffX, 2) + Math.Pow(diffY, 2));
            return (float)dist;
        }

        public float TargetAngle(Vector2 p1, Vector2 p2)
        {
            return TargetAngle(p1.X, p1.Y, p2.X, p2.Y);
        }

        public float TargetAngle(double x1, double y1, double x2, double y2)
        {
            double deltaX = (x2 - x1);
            double deltaY = (y2 - y1);
            return (float)Math.Atan2(deltaY, deltaX);
        }
    }
}
