using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;

namespace Black_Hole_Game
{
    class TitleScreenModule : IGameModule
    {
        Game1 game;
        Random rand;
        Label lblTitle;
        Button[] btnMenu;
        MassiveObject blackHole;
        MassiveObject superCore;
        Sprite background;
        

        public TitleScreenModule(Game1 game)
        {
            this.game = game;
            rand = new Random();
        }

        public void Reset()
        {
        }

        public void LoadContent(ContentManager content)
        {
            lblTitle = new Label(content, game.spriteBatch, game.bigfont);
            lblTitle.text = "The Black Hole Game";
            Vector2 size = game.font.MeasureString(lblTitle.text);
            lblTitle.position = new Vector2(400-size.X, 10);

            btnMenu = new Button[3];
            btnMenu[0] = new Button(content, game.spriteBatch, game.guifont);
            btnMenu[0].text = "PLAY!";
            btnMenu[0].scaleV = new Vector2(2.5f, 1.2f);
            btnMenu[0].color = Color.Orange;
            btnMenu[0].animations.Add(
                new OrbitalMovement( new Vector2(400, 240), 40, 0, 0.05f));

            btnMenu[1] = new Button(content, game.spriteBatch, game.guifont);
            btnMenu[1].text = "OPTIONS";
            btnMenu[1].color = Color.DarkRed;
            btnMenu[1].scaleV = new Vector2(2.1f, 1.0f);
            btnMenu[1].animations.Add(
                new OrbitalMovement(new Vector2(420, 220), 140, 0, 0.04f));

            btnMenu[2] = new Button(content, game.spriteBatch, game.guifont);
            btnMenu[2].text = "EXIT";
            btnMenu[2].color = Color.DarkSeaGreen;
            btnMenu[2].scaleV = new Vector2(1.6f, 0.8f);
            btnMenu[2].animations.Add(
                new OrbitalMovement(new Vector2(380, 260), 240, 0, 0.03f));

            background = new Sprite(game.Content, game.spriteBatch);
            background.Load("space");
            background.origin = Vector2.Zero;

            blackHole = new MassiveObject(game.Content, game.spriteBatch);
            blackHole.Load("blackhole");
            blackHole.position = new Vector2(400, 240);
            blackHole.scale = 4.0f;
            blackHole.mass = 40;
            blackHole.color = new Color(255, 100, 100, 200);
            blackHole.velocityAngular = 0.1f;

            superCore = new MassiveObject(game.Content, game.spriteBatch);
            superCore.image = blackHole.image;
            superCore.position = new Vector2(blackHole.position.X, blackHole.position.Y);
            superCore.scale = blackHole.scale * 0.4f;
            superCore.mass = 60;
            superCore.color = new Color(200, 100, 100, 180);
            superCore.velocityAngular = 4.0f;
            superCore.origin = new Vector2(64, 64);
        }

        public void Update(TouchLocation touch, GameTime gameTime)
        {
            blackHole.Update(gameTime);
            blackHole.Rotate();
            superCore.Update(gameTime);
            superCore.Rotate();


            int tapped = -1;
            int n = 0;
            foreach (Button btn in btnMenu)
            {
                btn.Update(touch);
                btn.Animate();

                if (btn.Tapped)
                    tapped = n;

                n++;
            }

            switch (tapped)
            {
                case 0: 
                    game.gameState = Game1.GameState.PLAYING;
                    break;
                case 1:
                    game.gameState = Game1.GameState.OPTIONS;
                    break;
                case 2:
                    game.Exit();
                    break;
            }
        }

        public void Draw(GameTime gameTime)
        {
            background.Draw();
            superCore.Draw();
            blackHole.Draw();
            lblTitle.Draw();

            foreach (Button btn in btnMenu)
            {
                btn.Draw();
            }
        }

    }
}

